@@ -1,5 +1,13 @@
+/*
+  This program is free software; you can redistribute it and/or modify
+  it under the terms of the GNU General Public License as published by
+  the Free Software Foundation; either version 2 of the License, or
+  (at your option) any later version.
+*/
 
-// (C)2003 Mickael Marchand <marchand@kde.org>
+/*
+  Copyright (C) 2003 Mickael Marchand <marchand@kde.org>
+*/
 
 #ifndef KONSOLE_PANEL_H
 #define KONSOLE_PANEL_H
@@ -12,13 +20,13 @@ class KonsolePanel : public ChatWindow
     Q_OBJECT
 
     public:
-        KonsolePanel(QWidget *p);
+        explicit KonsolePanel(QWidget *p);
         ~KonsolePanel();
 
         virtual void setName(const QString& newName) { ChatWindow::setName(newName); }
 
-        signals:
-        void deleted(ChatWindow* myself);
+    signals:
+        void closeView(ChatWindow* view);
 
     public slots:
         void partDestroyed();
