@@ -6,9 +6,8 @@
 */
 
 /*
-  begin:     Mon Jan 28 2002
-  copyright: (C) 2002 by Dario Abatianni
-  email:     eisfuchs@tigress.com
+  Copyright (C) 2002 Dario Abatianni <eisfuchs@tigress.com>
+  Copyright (C) 2005 Eike Hein <sho@eikehein.com>
 */
 
 #include <qhbox.h>
@@ -19,6 +18,7 @@
 #include <qtooltip.h>
 #include <qtextstream.h>
 #include <qwhatsthis.h>
+#include <qsplitter.h>
 
 #include <klocale.h>
 #include <kstandarddirs.h>
@@ -36,6 +36,7 @@
 #include "ircview.h"
 #include "ircviewbox.h"
 #include "common.h"
+#include "topiclabel.h"
 
 Query::Query(QWidget* parent) : ChatWindow(parent)
 {
@@ -45,9 +46,12 @@ Query::Query(QWidget* parent) : ChatWindow(parent)
 
     setChannelEncodingSupported(true);
 
+    m_headerSplitter = new QSplitter(Qt::Vertical, this);
+
+    m_initialShow = true;
     awayChanged=false;
     awayState=false;
-    QHBox *box = new QHBox(this);
+    QHBox *box = new QHBox(m_headerSplitter);
     addresseeimage = new QLabel(box, "query_image");
     addresseeimage->setSizePolicy(QSizePolicy::Fixed, QSizePolicy::Fixed);
     addresseeimage->hide();
@@ -55,15 +59,14 @@ Query::Query(QWidget* parent) : ChatWindow(parent)
     addresseelogoimage->setSizePolicy(QSizePolicy::Fixed, QSizePolicy::Fixed);
     addresseelogoimage->hide();
 
-    queryHostmask=new QLabel(box, "query_hostmask");
-    queryHostmask->setSizePolicy(QSizePolicy::Expanding, QSizePolicy::Fixed);
+    queryHostmask=new Konversation::TopicLabel(box, "query_hostmask");
 
     QString whatsthis = i18n("<qt>Some details of the person you are talking to in this query is shown in this bar.  The full name and hostmask is shown, along with any image or logo this person has associated with them in the KDE Addressbook.<p>See the <i>Konversation Handbook</i> for information on associating a nick with a contact in the Addressbook, and for an explanation of what the hostmask is.</qt>");
     QWhatsThis::add(addresseeimage, whatsthis);
     QWhatsThis::add(addresseelogoimage, whatsthis);
     QWhatsThis::add(queryHostmask, whatsthis);
 
-    IRCViewBox* ircBox = new IRCViewBox(this,0);
+    IRCViewBox* ircBox = new IRCViewBox(m_headerSplitter,0);
     setTextView(ircBox->ircView());               // Server will be set later in setServer();
     textView->setAcceptDrops(true);
     connect(textView,SIGNAL(filesDropped(const QStrList&)),this,SLOT(filesDropped(const QStrList&)));
@@ -71,16 +74,24 @@ Query::Query(QWidget* parent) : ChatWindow(parent)
 
     // link "Whois", "Ignore" ... menu items into ircview popup
     QPopupMenu* popup=textView->getPopup();
-    popup->insertItem(i18n("Whois"),Konversation::Whois);
-    popup->insertItem(i18n("Version"),Konversation::Version);
-    popup->insertItem(i18n("Ping"),Konversation::Ping);
+    popup->insertItem(i18n("&Whois"),Konversation::Whois);
+    popup->insertItem(i18n("&Version"),Konversation::Version);
+    popup->insertItem(i18n("&Ping"),Konversation::Ping);
     popup->insertSeparator();
+
+    popup->insertItem(i18n("Ignore"), Konversation::IgnoreNick);
+    popup->insertItem(i18n("Unignore"), Konversation::UnignoreNick);
+    popup->setItemVisible(Konversation::IgnoreNick, false);
+    popup->setItemVisible(Konversation::UnignoreNick, false);
+    popup->insertSeparator();
+
     if (kapp->authorize("allow_downloading"))
     {
         popup->insertItem(SmallIcon("2rightarrow"),i18n("Send &File..."),Konversation::DccSend);
+        popup->insertSeparator();
     }
-    popup->insertSeparator();
-    popup->insertItem(i18n("Ignore"),Konversation::IgnoreNick);
+
+    popup->insertItem(i18n("Add to Watched Nicks"), Konversation::AddNotify);
 
     // This box holds the input line
     QHBox* inputBox=new QHBox(this, "input_log_box");
@@ -92,7 +103,6 @@ Query::Query(QWidget* parent) : ChatWindow(parent)
 
     getTextView()->installEventFilter(queryInput);
     queryInput->installEventFilter(this);
-    queryInput->setCheckSpellingEnabled(Preferences::spellChecking());
 
     // connect the signals and slots
     connect(queryInput,SIGNAL (submit()),this,SLOT (queryTextEntered()) );
@@ -107,8 +117,6 @@ Query::Query(QWidget* parent) : ChatWindow(parent)
     connect(textView,SIGNAL (extendedPopup(int)),this,SLOT (popup(int)) );
     connect(textView,SIGNAL (autoText(const QString&)),this,SLOT (sendQueryText(const QString&)) );
 
-    connect(KonversationApplication::instance(), SIGNAL (appearanceChanged()),this,SLOT (updateAppearance()) );
-
     updateAppearance();
 
     setLog(Preferences::log());
@@ -123,11 +131,10 @@ void Query::setName(const QString& newName)
     if(ChatWindow::getName() == newName) return;  // no change, so return
 
     ChatWindow::setName(newName);
+
     // don't change logfile name if query name changes
     // This will prevent Nick-Changers to create more than one log file,
-    // unless we want this by turning the option Log Follows Nick off.
-
-    if((logName.isEmpty()) || !(Preferences::logFollowsNick()))
+    if (logName.isEmpty())
     {
         QString logName =  (Preferences::lowerLog()) ? getName().lower() : getName() ;
 
@@ -145,11 +152,11 @@ void Query::queryTextEntered()
 {
     QString line=queryInput->text();
     queryInput->clear();
-    if(line.lower()=="/clear")
+    if(line.lower()==Preferences::commandChar()+"clear")
     {
         textView->clear();
     }
-    else if(line.lower()=="/part")
+    else if(line.lower()==Preferences::commandChar()+"part")
     {
         m_server->closeQuery(getName());
     }
@@ -204,8 +211,23 @@ void Query::sendQueryText(const QString& sendLine)
             else if(!result.typeString.isEmpty()) appendQuery(result.typeString, result.output);
             else appendQuery(m_server->getNickname(), result.output);
         }
+        else if (result.outputList.count())
+        {
+            Q_ASSERT(result.type==Konversation::Message);
+            for ( QStringList::Iterator it = result.outputList.begin(); it != result.outputList.end(); ++it )
+            {
+                append(m_server->getNickname(), *it);
+            }
+        }
 
-        m_server->queue(result.toServer);
+        if (result.toServerList.count())
+        {
+            m_server->queueList(result.toServerList);
+        }
+        else //per the original code, an empty string could be queued
+        {
+            m_server->queue(result.toServer);
+        }
     } // for
 }
 
@@ -228,16 +250,10 @@ void Query::updateAppearance()
     queryInput->unsetPalette();
     queryInput->setPaletteForegroundColor(fg);
     queryInput->setPaletteBackgroundColor(bg);
-    queryInput->setFont(Preferences::textFont());
-
-    //  queryHostmask->setPaletteForegroundColor(fg);
-    //  queryHostmask->setPaletteBackgroundColor(bg);
-    //  queryHostmask->setFont(Preferences::textFont());
 
     getTextView()->unsetPalette();
-    getTextView()->setFont(Preferences::textFont());
 
-    if(Preferences::showBackgroundImage())
+    if (Preferences::showBackgroundImage())
     {
         getTextView()->setViewBackground(Preferences::color(Preferences::TextViewBackground),
             Preferences::backgroundImage());
@@ -247,6 +263,19 @@ void Query::updateAppearance()
         getTextView()->setViewBackground(Preferences::color(Preferences::TextViewBackground),
             QString::null);
     }
+
+    if (Preferences::customTextFont())
+    {
+        getTextView()->setFont(Preferences::textFont());
+        queryInput->setFont(Preferences::textFont());
+    }
+    else
+    {
+        getTextView()->setFont(KGlobalSettings::generalFont());
+        queryInput->setFont(KGlobalSettings::generalFont());
+    }
+
+    ChatWindow::updateAppearance();
 }
 
 void Query::textPasted(const QString& text)
@@ -291,6 +320,13 @@ void Query::showEvent(QShowEvent*)
         awayChanged=false;
         indicateAway(awayState);
     }
+
+    if(m_initialShow) {
+        m_initialShow = false;
+        QValueList<int> sizes;
+        sizes << queryHostmask->sizeHint().height() << (height() - queryHostmask->sizeHint().height());
+        m_headerSplitter->setSizes(sizes);
+    }
 }
 
 void Query::popup(int id)
@@ -303,7 +339,7 @@ void Query::popup(int id)
     switch(id)
     {
         case Konversation::Whois:
-            sendQueryText(Preferences::commandChar()+"WHOIS "+name+" "+name);
+            sendQueryText(Preferences::commandChar()+"WHOIS "+name+' '+name);
             break;
 
         case Konversation::IgnoreNick:
@@ -317,8 +353,22 @@ void Query::popup(int id)
                 "CloseQueryAfterIgnore");
               if(rc==KMessageBox::Yes) closeYourself();
               break;
-	    }
+        }
+        case Konversation::UnignoreNick:
+        {
+            QString question = i18n("Do you want to stop ignoring %1?").arg(name);
 
+            if (KMessageBox::warningContinueCancel(this, question, i18n("Unignore"), i18n("Unignore"), "UnignoreNick") ==
+                KMessageBox::Continue)
+            {
+                sendQueryText(Preferences::commandChar()+"UNIGNORE "+name);
+            }
+            break;
+        }
+        case Konversation::AddNotify:
+            if (!Preferences::isNotify(m_server->serverGroupSettings()->id(), name))
+                Preferences::addNotify(m_server->serverGroupSettings()->id(),name);
+            break;
         case Konversation::DccSend:
             sendQueryText(Preferences::commandChar()+"DCC SEND "+name);
             break;
@@ -355,16 +405,8 @@ void Query::sendFileMenu()
     emit sendFile(getName());
 }
 
-void Query::lostFocus()
-{
-    Preferences::setSpellChecking(queryInput->checkSpellingEnabled());
-    //Turn off spell checking when not focused to save some memory.
-    queryInput->setCheckSpellingEnabled(false);
-}
-
 void Query::childAdjustFocus()
 {
-    queryInput->setCheckSpellingEnabled(Preferences::spellChecking());
     queryInput->setFocus();
 }
 
@@ -490,7 +532,7 @@ bool Query::closeYourself()
 {
     int result=KMessageBox::warningContinueCancel(
         this,
-        i18n("Do you want close your query with %1?").arg(getName()),
+        i18n("Do you want to close your query with %1?").arg(getName()),
         i18n("Close Query"),
         i18n("Close"),
         "QuitQueryTab");
@@ -509,6 +551,27 @@ void Query::filesDropped(const QStrList& files)
     m_server->sendURIs(files,getName());
 }
 
+void Query::serverOnline(bool online)
+{
+    //queryInput->setEnabled(online);
+    getTextView()->setNickAndChannelContextMenusEnabled(online);
+
+    QPopupMenu* popup = getTextView()->getPopup();
+
+    if (popup)
+    {
+        popup->setItemEnabled(Konversation::Whois, online);
+        popup->setItemEnabled(Konversation::Version, online);
+        popup->setItemEnabled(Konversation::Ping, online);
+        popup->setItemEnabled(Konversation::IgnoreNick, online);
+        popup->setItemEnabled(Konversation::UnignoreNick, online);
+        popup->setItemEnabled(Konversation::AddNotify, online);
+
+        if (kapp->authorize("allow_downloading"))
+            popup->setItemEnabled(Konversation::DccSend, online);
+    }
+}
+
 void Query::emitUpdateInfo()
 {
     QString info;
@@ -525,14 +588,19 @@ void Query::emitUpdateInfo()
 // show quit message of nick if we see it
 void Query::quitNick(const QString& reason)
 {
-  QString displayReason;
+    QString displayReason = reason;
 
-  if(!reason.isEmpty())
-  {
-    displayReason=" ("+reason+")";
-  }
+    if (displayReason.isEmpty())
+    {
+        appendCommandMessage(i18n("Quit"),i18n("%1 has left this server.").arg(getName()),false);
+    }
+    else
+    {
+        if (displayReason.find(QRegExp("[\\0000-\\0037]"))!=-1)
+            displayReason+="\017";
 
-  appendCommandMessage(i18n("Quit"),i18n("%1 has left this server%2.").arg(getName()).arg(displayReason),false);
+        appendCommandMessage(i18n("Quit"),i18n("%1 has left this server (%2).").arg(getName()).arg(displayReason),false);
+    }
 }
 
 #include "query.moc"
